@@ -46,7 +46,7 @@ API Reference
 """
 from abc import ABC, abstractmethod
 import h5py
-from math import isclose
+from math import hypot, isclose
 import numpy as np
 from numbers import Real
 import os
@@ -380,7 +380,6 @@ class Beamline(ABC):
         """
         motor_positions = setup.diffractometer.motor_positions(
             setup=setup,
-            logfile=logfile,
             scan_number=scan_number,
         )
         # remove the motor positions corresponding to deleted frames during data
@@ -817,15 +816,7 @@ class BeamlineID01(Beamline):
             name="filename",
         )
 
-        if os.path.isfile(filename):
-            # filename is already the full path to the .spec file
-            return SpecFile(filename)
-        print(f"Could not find the spec file at {filename}")
-
-        if not os.path.isdir(root_folder):
-            raise ValueError(f"The directory {root_folder} does not exist")
-        path = root_folder + filename
-        print(f"Trying to load the spec file at {path}")
+        path = util.find_file(filename=filename, default_folder=root_folder)
         return SpecFile(path)
 
     @property
@@ -1463,14 +1454,14 @@ class BeamlineP10(Beamline):
         if os.path.isfile(filename):
             # filename is already the full path to the .fio file
             return filename
-        print(f"Could not find the spec file at {filename}")
+        print(f"Could not find the fio file at: {filename}")
 
         if not os.path.isdir(root_folder):
             raise ValueError(f"The directory {root_folder} does not exist")
 
         # return the path to the .fio file
         path = root_folder + filename + "/" + filename + ".fio"
-        print(f"Trying to load the fio file at {path}")
+        print(f"Trying to load the fio file at: {path}")
         return path
 
     @property
@@ -1516,13 +1507,16 @@ class BeamlineP10(Beamline):
 
         """
         specfile = kwargs.get("specfile_name")
-        if not os.path.isfile(specfile):
+        default_specfile = sample_name + "_{:05d}".format(scan_number)
+        if specfile is None or not os.path.isfile(specfile):
             # default to the usual position of .fio at P10
-            specfile = sample_name + "_{:05d}".format(scan_number)
+            specfile = default_specfile
 
-        homedir = root_folder + specfile + "/"
+        homedir = root_folder + default_specfile + "/"
         default_dirname = "e4m/"
-        template_imagefile = specfile + template_imagefile
+
+        if template_imagefile is not None:
+            template_imagefile = default_specfile + template_imagefile
         return homedir, default_dirname, specfile, template_imagefile
 
     def process_positions(
@@ -1837,7 +1831,7 @@ class BeamlineP10SAXS(BeamlineP10):
             interp_angle[x_interp == 0]
         )
 
-        interp_radius = np.multiply(sign_array, np.sqrt(x_interp ** 2 + z_interp ** 2))
+        interp_radius = np.multiply(sign_array, hypot(x_interp, z_interp))
 
         if debugging:
             gu.imshow_plot(
@@ -2363,15 +2357,7 @@ class Beamline34ID(Beamline):
             name="filename",
         )
 
-        if os.path.isfile(filename):
-            # filename is already the full path to the .spec file
-            return SpecFile(filename)
-        print(f"Could not find the spec file at {filename}")
-
-        if not os.path.isdir(root_folder):
-            raise ValueError(f"The directory {root_folder} does not exist")
-        path = root_folder + filename
-        print(f"Trying to load the spec file at {path}")
+        path = util.find_file(filename=filename, default_folder=root_folder)
         return SpecFile(path)
 
     @property
@@ -2379,7 +2365,7 @@ class Beamline34ID(Beamline):
         """
         Horizontal detector orientation expressed in the laboratory frame.
 
-        We look at the detector from upstream, detector X is opposite to the outboard
+        We look at the detector from downstream, detector X is along the outboard
         direction. The laboratory frame convention is (z downstream, y vertical,
         x outboard).
         """
@@ -2531,7 +2517,7 @@ class Beamline34ID(Beamline):
                     "Circle below theta not implemented for 34ID-C"
                 )
             if verbose:
-                print("rocking angle is theta, no grazing angle (phi above theta)")
+                print("rocking angle is theta, no grazing angle (chi, phi above theta)")
             # rocking theta angle anti-clockwise around y
             mymatrix[:, 0] = (
                 2
@@ -2582,19 +2568,18 @@ class Beamline34ID(Beamline):
             )
 
         elif rocking_angle == "outofplane":
-            if isinstance(grazing_angle, Real):
-                grazing_angle = (grazing_angle,)
             valid.valid_container(
                 grazing_angle,
                 container_types=(tuple, list),
                 item_types=Real,
-                length=1,
+                length=2,
                 name="grazing_angle",
             )
             if verbose:
                 print(
                     "rocking angle is phi,"
-                    f" theta={grazing_angle[0] * 180 / np.pi:.3f} deg"
+                    f" theta={grazing_angle[0] * 180 / np.pi:.3f} deg,"
+                    f" chi={grazing_angle[1] * 180 / np.pi:.3f} deg"
                 )
             # rocking phi angle anti-clockwise around x
             mymatrix[:, 0] = (
@@ -2627,15 +2612,34 @@ class Beamline34ID(Beamline):
                 * distance
                 * np.array(
                     [
-                        -np.sin(grazing_angle[0]) * np.sin(outofplane),
-                        np.cos(grazing_angle[0])
-                        * (np.cos(inplane) * np.cos(outofplane) - 1),
-                        -np.cos(grazing_angle[0]) * np.sin(outofplane),
+                        (
+                            np.cos(grazing_angle[1])
+                            * (1 - np.cos(inplane) * np.cos(outofplane))
+                            - np.sin(grazing_angle[0])
+                            * np.sin(grazing_angle[1])
+                            * np.sin(outofplane)
+                        ),
+                        np.sin(grazing_angle[1])
+                        * (
+                            np.cos(grazing_angle[0])
+                            * (np.cos(inplane) * np.cos(outofplane) - 1)
+                            + np.sin(grazing_angle[0])
+                            * np.sin(inplane)
+                            * np.cos(outofplane)
+                        ),
+                        (
+                            np.cos(grazing_angle[1])
+                            * np.sin(inplane)
+                            * np.cos(outofplane)
+                            - np.sin(grazing_angle[1])
+                            * np.cos(grazing_angle[0])
+                            * np.sin(outofplane)
+                        ),
                     ]
                 )
             )
             q_offset[0] = (
-                2 * np.pi / lambdaz * distance * np.cos(outofplane) * np.sin(inplane)
+                2 * np.pi / lambdaz * distance * np.sin(inplane) * np.cos(outofplane)
             )
             q_offset[1] = 2 * np.pi / lambdaz * distance * np.sin(outofplane)
             q_offset[2] = (
