@@ -59,10 +59,12 @@ API Reference
 """
 
 from abc import ABC, abstractmethod
+from functools import partial
 import numpy as np
 from numbers import Real, Integral
 import os
 import pathlib
+from typing import Any, Dict, List, Union
 
 from bcdi.utils import validation as valid
 
@@ -89,6 +91,54 @@ def create_detector(name, **kwargs):
     raise NotImplementedError(f"No implementation for the {name} detector")
 
 
+def create_roi(dic: Dict[str, Any]) -> Any:
+    """
+    Load "roi_detector" from the dictionary of parameters and update it.
+
+    If the keys "x_bragg" or "y_bragg", it will consider that the current values in
+    roi_detector define a window around the Bragg peak position and the final output
+    will be:
+    [y_bragg - roi_detector[0], y_bragg + roi_detector[1],
+    x_bragg - roi_detector[2], x_bragg + roi_detector[3]].
+
+    If a key is not defined, it will consider that the values of roi_detector are
+    absolute pixels positions, e.g. if only "y_bragg" is defined, the output will be
+    [y_bragg - roi_detector[0], y_bragg + roi_detector[1],
+    roi_detector[2], roi_detector[3]].
+
+    Accordingly, if none of the keys are defined, the output will be:
+    [roi_detector[0], roi_detector[1], roi_detector[2], roi_detector[3]].
+
+    :param dic: a dictionary of parameters
+    :return: the calculated region of interest [Vstart, Vstop, Hstart, Hstop] or None
+    """
+    valid.valid_container(dic, container_types=dict, name="dic")
+    roi = dic.get("roi_detector")
+    valid.valid_container(
+        roi,
+        container_types=(tuple, list, np.ndarray),
+        length=4,
+        item_types=int,
+        allow_none=True,
+        name="roi_detector",
+    )
+
+    # update the ROI
+    if roi is not None:
+        y_bragg = dic.get("y_bragg")
+        if y_bragg is not None:
+            valid.valid_item(y_bragg, allowed_types=int, name="y_bragg")
+            roi[0] = y_bragg - roi[0]
+            roi[1] = y_bragg + roi[1]
+
+        x_bragg = dic.get("x_bragg")
+        if x_bragg is not None:
+            valid.valid_item(x_bragg, allowed_types=int, name="x_bragg")
+            roi[2] = x_bragg - roi[2]
+            roi[3] = x_bragg + roi[3]
+    return roi
+
+
 class Detector(ABC):
     """
     Class to handle the configuration of the detector used for data acquisition.
@@ -228,9 +278,35 @@ class Detector(ABC):
 
     @linearity_func.setter
     def linearity_func(self, value):
-        if value is not None and not callable(value):
-            raise TypeError(f"linearity_func should be a function, got {type(value)}")
-        self._linearity_func = value
+        def poly4(array_1d, coeffs):
+            """
+            Define a 4th order polynomial and apply it on a 1D array.
+
+            :param array_1d: a numpy 1D array
+            :param coeffs: sequence of 5 Real numbers, the coefficients [a, b, c, d, e]
+             of the polynomial ax^4 + bx^3 + cx^2 + dx + e
+            :return: the updated 1D array
+            """
+            return (
+                coeffs[0] * array_1d ** 4
+                + coeffs[1] * array_1d ** 3
+                + coeffs[2] * array_1d ** 2
+                + coeffs[3] * array_1d
+                + coeffs[4]
+            )
+
+        if value is None:
+            self._linearity_func = None
+            return
+
+        valid.valid_container(
+            value,
+            container_types=(tuple, list, np.ndarray),
+            length=5,
+            item_types=Real,
+            name="linearity_func",
+        )
+        self._linearity_func = partial(poly4, coeffs=value)
 
     @property
     def name(self):
@@ -458,7 +534,7 @@ class Detector(ABC):
             container_types=str,
             min_length=0,
             allow_none=True,
-            name="Detector.imagefile",
+            name="template_imagefile",
         )
         self._template_imagefile = value
 
@@ -554,11 +630,11 @@ class Detector(ABC):
         :param data: a 2D numpy array
         :return: the corrected data array
         """
-        if self.linearity_func is not None:
+        if self.linearity_func is not None and callable(self.linearity_func):
             valid.valid_ndarray(data, ndim=2)
             data = data.astype(float)
             nby, nbx = data.shape
-            return self.linearity_func(data.flatten()).reshape((nby, nbx))
+            return self.linearity_func(array_1d=data.flatten()).reshape((nby, nbx))
         return data
 
     def mask_detector(
