@@ -88,8 +88,8 @@ def center_fft(
         allowed_kwargs={"fix_bragg", "fix_size", "pad_size", "q_values"},
         name="kwargs",
     )
-    fix_bragg = kwargs.get("fix_bragg", [])
-    fix_size = kwargs.get("fix_size", [])
+    fix_bragg = kwargs.get("fix_bragg")
+    fix_size = kwargs.get("fix_size")
     pad_size = kwargs.get("pad_size", [])
     q_values = kwargs.get("q_values", [])
 
@@ -120,7 +120,7 @@ def center_fft(
     else:
         raise ValueError("Incorrect value for 'centering' parameter")
 
-    if len(fix_bragg) != 0:
+    if fix_bragg:
         if len(fix_bragg) != 3:
             raise ValueError("fix_bragg should be a list of 3 integers")
         z0, y0, x0 = fix_bragg
@@ -552,7 +552,10 @@ def center_fft(
         pad_width = np.zeros(
             6, dtype=int
         )  # do nothing or crop the data, starting_frame should be 0
-        if len(fix_size) == 6:
+        if fix_size:
+            if len(fix_size) != 6:
+                raise ValueError("fix_bragg should be a list of 3 integers")
+
             # take binning into account
             fix_size[2] = int(fix_size[2] // detector.binning[1])
             fix_size[3] = int(fix_size[3] // detector.binning[1])
@@ -681,8 +684,14 @@ def grid_bcdi_labframe(
        of the interpolation range. The first value is for the data, the second for the
        mask. Default is (0, 0)
 
-    :return: the data and mask interpolated in the laboratory frame, q values
-     (downstream, vertical up, outboard). q values are in inverse angstroms.
+    :return:
+
+     - the data interpolated in the laboratory frame
+     - the mask interpolated in the laboratory frame
+     - a tuple of three 1D vectors of q values (qx, qz, qy)
+     - a numpy array of shape (3, 3): transformation matrix from the detector
+       frame to the laboratory/crystal frame
+
     """
     valid.valid_ndarray(arrays=(data, mask), ndim=3)
     # check and load kwargs
@@ -721,7 +730,7 @@ def grid_bcdi_labframe(
         " the result will be in the laboratory frame"
     )
     string = "linmat_reciprocal_space_"
-    (interp_data, interp_mask), q_values = setup.ortho_reciprocal(
+    (interp_data, interp_mask), q_values, transfer_matrix = setup.ortho_reciprocal(
         arrays=(data, mask),
         verbose=True,
         debugging=debugging,
@@ -823,7 +832,7 @@ def grid_bcdi_labframe(
             reciprocal_space=True,
         )
 
-    return interp_data, interp_mask, q_values
+    return interp_data, interp_mask, q_values, transfer_matrix
 
 
 def grid_bcdi_xrayutil(
@@ -1005,7 +1014,6 @@ def grid_bcdi_xrayutil(
 
 
 def load_bcdi_data(
-    logfile,
     scan_number,
     detector,
     setup,
@@ -1020,8 +1028,6 @@ def load_bcdi_data(
     """
     Load Bragg CDI data, apply optional threshold, normalization and binning.
 
-    :param logfile: file containing the information about the scan and image numbers
-     (specfile, .fio...)
     :param scan_number: the scan number to load
     :param detector: an instance of the class Detector
     :param setup: an instance of the class Setup
@@ -1066,7 +1072,6 @@ def load_bcdi_data(
     )
 
     rawdata, rawmask, monitor, frames_logical = setup.diffractometer.load_check_dataset(
-        logfile=logfile,
         scan_number=scan_number,
         detector=detector,
         setup=setup,
@@ -1124,7 +1129,6 @@ def load_bcdi_data(
 def reload_bcdi_data(
     data,
     mask,
-    logfile,
     scan_number,
     detector,
     setup,
@@ -1137,8 +1141,6 @@ def reload_bcdi_data(
 
     :param data: the 3D data array
     :param mask: the 3D mask array
-    :param logfile: file containing the information about the scan and image numbers
-     (specfile, .fio...)
     :param scan_number: the scan number to load
     :param detector: an instance of the class Detector
     :param setup: an instance of the class Setup
@@ -1185,9 +1187,7 @@ def reload_bcdi_data(
     else:  # use the default monitor of the beamline
         monitor = setup.diffractometer.read_monitor(
             scan_number=scan_number,
-            logfile=logfile,
-            beamline=setup.beamline,
-            actuators=setup.actuators,
+            setup=setup,
         )
 
         print("Intensity normalization using " + normalize_method)
