@@ -14,7 +14,6 @@ import tkinter as tk
 from tkinter import filedialog
 import matplotlib.ticker as ticker
 import bcdi.postprocessing.postprocessing_utils as pu
-import bcdi.preprocessing.preprocessing_utils as pru
 from bcdi.utils import image_registration as reg
 import bcdi.graph.graph_utils as gu
 import bcdi.utils.utilities as util
@@ -108,11 +107,11 @@ fieldnames = ["scans", "modulus", "phase", "strain"]
 datasets = {new_list: [] for new_list in fieldnames}  # create dictionnary
 datasets["scans"].append(scans)
 
-for index in range(len(scans)):
+for index, item in enumerate(scans):
 
     file_path = filedialog.askopenfilename(
         initialdir=rootfolder,
-        title="Select amp-disp-strain file for S" + str(scans[index]),
+        title="Select amp-disp-strain file for S" + str(item),
         filetypes=[("NPZ", "*.npz")],
     )
     npzfile = np.load(file_path)
@@ -123,7 +122,7 @@ for index in range(len(scans)):
     numz, numy, numx = amp.shape
 
     # pad the dataset to the desired the field #
-    pixel_spacing = tick_spacing / voxel_size  # TODO: allow for different voxel sizes
+    pixel_spacing = tick_spacing / voxel_size
     pixel_FOV = int(
         np.rint((field_of_view / voxel_size) / 2)
     )  # half-number of pixels corresponding to the FOV
@@ -202,18 +201,18 @@ for index in range(len(scans)):
         phase, extent_phase = pu.unwrap(
             amp * np.exp(1j * phase), support_threshold=0.05, debugging=debug
         )
-        phase = pru.wrap(phase, start_angle=-extent_phase / 2, range_angle=extent_phase)
+        phase = util.wrap(
+            phase, start_angle=-extent_phase / 2, range_angle=extent_phase
+        )
         phase = phase - phase[zcom, ycom, xcom]
         phase, extent_phase = pu.unwrap(
             amp * np.exp(1j * phase), support_threshold=0.05, debugging=debug
         )
-        phase = pru.wrap(
+        phase = util.wrap(
             phase, start_angle=-extent_phase / 2, range_angle=extent_phase
         )  # rewrap after modifying phase
         ref_amp = np.copy(amp)
     else:  # align it with the reference object
-        # TODO: interpolate object if the shape is different from ref_amp
-        #  (different voxel sizes between datasets)
         shiftz, shifty, shiftx = reg.getimageregistration(ref_amp, amp, precision=1000)
         print(
             "Shift of array", index, "with the reference array:", shiftz, shifty, shiftx
@@ -225,12 +224,14 @@ for index in range(len(scans)):
         phase, extent_phase = pu.unwrap(
             amp * np.exp(1j * phase), support_threshold=0.05, debugging=False
         )
-        phase = pru.wrap(phase, start_angle=-extent_phase / 2, range_angle=extent_phase)
+        phase = util.wrap(
+            phase, start_angle=-extent_phase / 2, range_angle=extent_phase
+        )
         phase = phase - phase[zcom, ycom, xcom]
         phase, extent_phase = pu.unwrap(
             amp * np.exp(1j * phase), support_threshold=0.05, debugging=False
         )
-        phase = pru.wrap(
+        phase = util.wrap(
             phase, start_angle=-extent_phase / 2, range_angle=extent_phase
         )  # rewrap after modifying phase
     print(
@@ -294,7 +295,7 @@ for index in range(len(scans)):
     bulk = pu.find_bulk(amp=amp, support_threshold=isosurface, method=isosurface_method)
 
     np.savez_compressed(
-        savedir + "S" + str(scans[index]) + "_amp_disp_strain_matched" + comment,
+        savedir + "S" + str(item) + "_amp_disp_strain_matched" + comment,
         amp=amp,
         displacement=phase,
         bulk=bulk,
