@@ -8,6 +8,8 @@
 #         Jerome Carnis, carnis_jerome@yahoo.fr
 
 import numpy as np
+import os
+from pyfakefs import fake_filesystem_unittest
 import unittest
 from bcdi.experiment.beamline import create_beamline, Beamline
 from bcdi.experiment.diffractometer import (
@@ -97,12 +99,12 @@ class TestBeamline(unittest.TestCase):
 
     def test_find_inplane_34ID(self):
         beamline = create_beamline("34ID")
-        diffractometer = Diffractometer34ID(sample_offsets=(0, 0))
+        diffractometer = Diffractometer34ID(sample_offsets=(0, 90, 0))
         self.assertTrue(beamline.find_inplane(diffractometer) == 0)
 
     def test_find_outofplane_34ID(self):
         beamline = create_beamline("34ID")
-        diffractometer = Diffractometer34ID(sample_offsets=(0, 0))
+        diffractometer = Diffractometer34ID(sample_offsets=(0, 90, 0))
         self.assertTrue(beamline.find_outofplane(diffractometer) == 1)
 
 
@@ -706,7 +708,7 @@ class TestBeamlineNANOMAX(unittest.TestCase):
             )
 
 
-class TestBeamlineP10(unittest.TestCase):
+class TestBeamlineP10(fake_filesystem_unittest.TestCase):
     """Tests related to P10 beamline instantiation."""
 
     def setUp(self):
@@ -777,6 +779,34 @@ class TestBeamlineP10(unittest.TestCase):
         )
         self.assertEqual(template_imagefile, "S_00001_master.h5")
 
+    def test_init_paths_specfile_full_path(self):
+        self.setUpPyfakefs()
+        valid_path = "/gpfs/bcdi/data"
+        os.makedirs(valid_path)
+        with open(valid_path + "/dummy.fio", "w") as f:
+            f.write("dummy")
+
+        params = {
+            "root_folder": self.root_dir,
+            "sample_name": self.sample_name,
+            "scan_number": self.scan_number,
+            "specfile_name": valid_path + "/dummy.fio",
+            "template_imagefile": self.template_imagefile,
+        }
+        (
+            homedir,
+            default_dirname,
+            specfile,
+            template_imagefile,
+        ) = self.beamline.init_paths(**params)
+        self.assertEqual(
+            homedir,
+            self.root_dir + self.sample_name + "_{:05d}".format(self.scan_number) + "/",
+        )
+        self.assertEqual(default_dirname, "e4m/")
+        self.assertEqual(specfile, params["specfile_name"])
+        self.assertEqual(template_imagefile, "S_00001_master.h5")
+
     def test_init_qconversion(self):
         _, offsets = self.beamline.init_qconversion(
             conversion_table=self.conversion_table,
@@ -1158,7 +1188,7 @@ class TestBeamline34ID(unittest.TestCase):
         self.template_imagefile = None
         self.specfile_name = "test_spec"
         self.beamline = create_beamline("34ID")
-        self.diffractometer = Diffractometer34ID(sample_offsets=(0, 0))
+        self.diffractometer = Diffractometer34ID(sample_offsets=None)
         self.beam_direction = np.array([1, 0, 0])
         self.offset_inplane = 1
         self.params = {
@@ -1226,7 +1256,7 @@ class TestBeamline34ID(unittest.TestCase):
             self.diffractometer.detector_circles
         )
         self.assertEqual(len(offsets), nb_circles)
-        self.assertEqual(offsets, [0, 0, self.offset_inplane, 0])
+        self.assertEqual(offsets, [0, 0, 0, self.offset_inplane, 0])
 
     def test_inplane_coeff(self):
         self.assertEqual(self.beamline.inplane_coeff(self.diffractometer), 1)
@@ -1274,7 +1304,7 @@ class TestBeamline34ID(unittest.TestCase):
 
     def test_transformation_matrix_outofplane(self):
         matrix, q_offset = self.beamline.transformation_matrix(
-            grazing_angle=(4.5,),
+            grazing_angle=(4.5, 89),
             rocking_angle="outofplane",
             **self.params,
         )
@@ -1283,9 +1313,9 @@ class TestBeamline34ID(unittest.TestCase):
                 matrix,
                 np.array(
                     [
-                        [2.88286898e05, 5.16236394e04, 8.31952065e-03],
-                        [-0.00000000e00, 3.32652707e05, 1.19402761e-02],
-                        [-1.90559381e05, 7.80985893e04, 1.79403169e-03],
+                        [2.88286898e05, 5.16236394e04, 3.60537340e-02],
+                        [-0.00000000e00, 3.32652707e05, 2.42895238e-02],
+                        [-1.90559381e05, 7.80985893e04, -6.96460831e-03],
                     ]
                 ),
                 rtol=1e-09,
@@ -1309,34 +1339,12 @@ class TestBeamline34ID(unittest.TestCase):
             )
 
     def test_transformation_matrix_outofplane_grazing_float(self):
-        matrix, q_offset = self.beamline.transformation_matrix(
-            grazing_angle=4.5,
-            rocking_angle="outofplane",
-            **self.params,
-        )
-        self.assertTrue(
-            np.allclose(
-                matrix,
-                np.array(
-                    [
-                        [2.88286898e05, 5.16236394e04, 8.31952065e-03],
-                        [-0.00000000e00, 3.32652707e05, 1.19402761e-02],
-                        [-1.90559381e05, 7.80985893e04, 1.79403169e-03],
-                    ]
-                ),
-                rtol=1e-09,
-                atol=1e-09,
+        with self.assertRaises(TypeError):
+            self.beamline.transformation_matrix(
+                grazing_angle=4.5,
+                rocking_angle="outofplane",
+                **self.params,
             )
-        )
-
-        self.assertTrue(
-            np.allclose(
-                q_offset,
-                np.array([-3.33515597, 1.70215127, -11.32876093]),
-                rtol=1e-09,
-                atol=1e-09,
-            )
-        )
 
     def test_transformation_matrix_energy_scan(self):
         with self.assertRaises(NotImplementedError):
